import { type AfterViewInit } from '@angular/core';
import type { ElementRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Component for overlay panel.
 */
export declare class OverlayComponent implements AfterViewInit {
    /** Title of the overlay. */
    overlayTitle: string;
    /** If the overlay is open or not. */
    active: boolean;
    /** Icon of the overlay header. */
    icon: string;
    /** If the overlay is resizable. */
    resizable: boolean;
    /** If the overlay body is transparent or not. */
    transparentBody: boolean;
    /** If the aspect ratio is kept fixed or not. */
    keepAspectRatioFixed: boolean;
    /** If the overlay body is visible or not. */
    showBody: boolean;
    /** Aspect ratio of the overlay view. */
    aspectRatio: number;
    /** Complete overlay card containing both header and body. */
    overlayCard: ElementRef;
    /** Handle for resizing the overlay. */
    resizeHandleCorner: ElementRef;
    /** Minimum resizable width. */
    private MIN_RES_WIDTH;
    /** Minimum resizable height */
    private MIN_RES_HEIGHT;
    /**
     * Move the resizable handle to the bottom right after the component is created.
     */
    ngAfterViewInit(): void;
    /**
     * Resize the overlay card when the resize handle is dragged.
     */
    onResize(): void;
    /**
     * Reset resize handle position.
     */
    resetHandlePosition(): void;
    /**
     * Set the position of the resize handle using transform3d.
     * @param overlayRect Bounding client rectangle of the overlay card.
     * @param dragRect Bounding client rectangle of the resize handle.
     */
    private setHandleTransform;
    static ɵfac: i0.ɵɵFactoryDeclaration<OverlayComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<OverlayComponent, "app-overlay", never, { "overlayTitle": { "alias": "overlayTitle"; "required": false; }; "active": { "alias": "active"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "resizable": { "alias": "resizable"; "required": false; }; "transparentBody": { "alias": "transparentBody"; "required": false; }; "keepAspectRatioFixed": { "alias": "keepAspectRatioFixed"; "required": false; }; }, {}, never, ["*"], false, never>;
}
